@@ -3,10 +3,10 @@ from .excel.excel_file import ExcelFile
 from .excel.excel_sheet import ExcelSheet
 from .buildables.layout.column import Column
 from .buildables.layout.row import Row
-from .buildables.layout.table import Table
+from .buildables.layout.table import Table, TableColumn
 from .buildables.non_layout.excel_cell import ExcelCell
 from .sizes.dimension import FixedWidth, AutoWidth, Dimension, RowDimension, ColumnDimension 
-from .styling.border import BorderStyle, BorderSide
+from .styling.border import BorderStyle, BorderSide, Border
 from .styling.color import Color, Colors
 from .styling.fill import Fill
 from .styling.style import Style
